pub(super) struct CompactionStatus {
pub(super) region_id: RegionId,
pub(super) version_control: Arc<VersionControl>,
pub(super) access_layer: AccessLayerRef,
pub(super) active: ActiveCompaction,
pub(super) pending_request: Option<PendingCompaction>,
pub(super) pending_ddl_requests: Vec<SenderDdlRequest>,
}Expand description
Status of running and pending region compaction tasks.
Fields
region_id: RegionIdId of the region.
version_control: Arc<VersionControl>Version control of the region.
access_layer: AccessLayerRefAccess layer of the region.
active: ActiveCompactionCurrent compaction lifecycle.
pending_request: Option<PendingCompaction>A manual compaction waiting for the current automatic compaction to finish.
A manual request is rejected if the current compaction is also manual. Automatic requests are merged into the active compaction instead of using this slot.
pending_ddl_requests: Vec<SenderDdlRequest>Pending DDL requests that should run when compaction is done.
Although SenderDdlRequest can wrap any DDL variant, production code only queues
crate::request::DdlRequest::Truncate and crate::request::DdlRequest::EnterStaging here. Both must serialize with
compaction so they observe the version after compaction terminates.
Implementations
Sourceimpl CompactionStatus
impl CompactionStatus
Sourcepub(super) fn new(
region_id: RegionId,
version_control: Arc<VersionControl>,
access_layer: AccessLayerRef,
plan_id: u64,
trigger: CompactionTrigger,
) -> CompactionStatus
pub(super) fn new( region_id: RegionId, version_control: Arc<VersionControl>, access_layer: AccessLayerRef, plan_id: u64, trigger: CompactionTrigger, ) -> CompactionStatus
Creates a new picking CompactionStatus.
pub(super) fn start_picking_with_trigger( &mut self, plan_id: u64, trigger: CompactionTrigger, )
pub(super) fn start_regular_picking(&mut self, plan_id: u64)
pub(super) fn is_picking(&self, expected_plan_id: u64) -> bool
pub(super) fn accept_plan(&self, expected_plan_id: u64) -> bool
pub(super) fn is_manual_compaction(&self) -> bool
pub(super) fn matches_execution(&self, execution: &CompactionExecution) -> bool
pub(super) fn request_cancel(&mut self) -> RequestCancelResult
pub(super) fn mark_automatic_trigger(&mut self)
Sourcepub(super) fn merge_waiter(&mut self, waiter: OptionOutputTx)
pub(super) fn merge_waiter(&mut self, waiter: OptionOutputTx)
Merge the waiter to the pending compaction.
pub(super) fn take_waiters(&mut self) -> Vec<OutputTx>
pub(super) fn extend_waiters(&mut self, waiters: Vec<OutputTx>)
pub(super) fn append_waiters(&mut self, waiters: &mut Vec<OutputTx>)
pub(super) fn set_phase(&mut self, phase: CompactionPhase)
Sourcepub(super) fn set_pending_request(&mut self, pending: PendingCompaction)
pub(super) fn set_pending_request(&mut self, pending: PendingCompaction)
Sets a pending manual compaction request, replacing an older pending request.
pub(super) fn on_failure(self, err: Arc<Error>)
pub(super) fn on_cancel(self) -> Vec<SenderDdlRequest>
Sourcepub(super) fn new_compaction_request(
&self,
request_sender: Sender<WorkerRequestWithTime>,
engine_config: Arc<MitoConfig>,
cache_manager: CacheManagerRef,
manifest_ctx: &Arc<ManifestContext>,
listener: WorkerListener,
schema_metadata_manager: SchemaMetadataManagerRef,
max_parallelism: usize,
) -> CompactionRequest
pub(super) fn new_compaction_request( &self, request_sender: Sender<WorkerRequestWithTime>, engine_config: Arc<MitoConfig>, cache_manager: CacheManagerRef, manifest_ctx: &Arc<ManifestContext>, listener: WorkerListener, schema_metadata_manager: SchemaMetadataManagerRef, max_parallelism: usize, ) -> CompactionRequest
Creates an immutable request for background compaction planning.